import { LogLevel } from '@livy/contracts/lib/log-level';
import { LineFormatter, LineFormatterOptions } from '@livy/line-formatter';
import { DateTime } from 'luxon';
export interface AnsiLineFormatterOptions extends LineFormatterOptions {
    /**
     * Whether records should be highlighted with ANSI escape sequences
     * If not provided (or set to `undefined`), color support is going
     * to be automatically detected
     */
    decorated: boolean | undefined;
}
/**
 * Formats log records as single lines with terminal highlighting
 */
export declare class AnsiLineFormatter extends LineFormatter {
    /**
     * Whether records should be highlighted with ANSI escape sequences
     */
    decorated: boolean | undefined;
    constructor({ decorated, ...options }?: Partial<AnsiLineFormatterOptions>);
    /**
     * @inheritdoc
     */
    protected formatDatetime(datetime: DateTime): string;
    /**
     * @inheritdoc
     */
    protected formatLevel(level: LogLevel): string;
    /**
     * @inheritdoc
     */
    protected formatData(object: any, ignoreEmpty: boolean): any;
    /**
     * Check whether the formatter should use ANSI codes to decorate log records
     */
    shouldDecorate(): boolean;
}
